@@ -9,9 +9,9 @@ from typing import Dict, List, Tuple, Union
 
 import numpy as np
 import pandas as pd
-import plotly
 import plotly.express as px
 import plotly.graph_objects as go
+import plotly.io._html
 import scipy.stats as sps
 
 from blackboxopt import Evaluation
